==> zio-aws-sesv2_3-5.17.152.1-sources.jar: zio/aws/sesv2/model/Body.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Body(
    text: Option[zio.aws.sesv2.model.Content] = None,
    html: Option[zio.aws.sesv2.model.Content] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.sesv2.model.Body = {
    import Body.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.Body
      .builder()
      .optionallyWith(text.map(value => value.buildAwsValue()))(_.text)
      .optionallyWith(html.map(value => value.buildAwsValue()))(_.html)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.Body.ReadOnly =
    zio.aws.sesv2.model.Body.wrap(buildAwsValue())
}
object Body {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.sesv2.model.Body] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.Body = zio.aws.sesv2.model.Body(
      text.map(value => value.asEditable),
      html.map(value => value.asEditable)
    )
    def text: Option[zio.aws.sesv2.model.Content.ReadOnly]
    def html: Option[zio.aws.sesv2.model.Content.ReadOnly]
    def getText: ZIO[Any, AwsError, zio.aws.sesv2.model.Content.ReadOnly] =
      AwsError.unwrapOptionField("text", text)
    def getHtml: ZIO[Any, AwsError, zio.aws.sesv2.model.Content.ReadOnly] =
      AwsError.unwrapOptionField("html", html)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.Body
  ) extends zio.aws.sesv2.model.Body.ReadOnly {
    override val text: Option[zio.aws.sesv2.model.Content.ReadOnly] = scala
      .Option(impl.text())
      .map(value => zio.aws.sesv2.model.Content.wrap(value))
    override val html: Option[zio.aws.sesv2.model.Content.ReadOnly] = scala
      .Option(impl.html())
      .map(value => zio.aws.sesv2.model.Content.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.Body
  ): zio.aws.sesv2.model.Body.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sesv2_3-6.20.78.1-sources.jar: zio/aws/sesv2/model/Body.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Body(
    text: Optional[zio.aws.sesv2.model.Content] = Optional.Absent,
    html: Optional[zio.aws.sesv2.model.Content] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.sesv2.model.Body = {
    import Body.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.Body
      .builder()
      .optionallyWith(text.map(value => value.buildAwsValue()))(_.text)
      .optionallyWith(html.map(value => value.buildAwsValue()))(_.html)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.Body.ReadOnly =
    zio.aws.sesv2.model.Body.wrap(buildAwsValue())
}
object Body {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.sesv2.model.Body] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.Body = zio.aws.sesv2.model.Body(
      text.map(value => value.asEditable),
      html.map(value => value.asEditable)
    )
    def text: Optional[zio.aws.sesv2.model.Content.ReadOnly]
    def html: Optional[zio.aws.sesv2.model.Content.ReadOnly]
    def getText: ZIO[Any, AwsError, zio.aws.sesv2.model.Content.ReadOnly] =
      AwsError.unwrapOptionField("text", text)
    def getHtml: ZIO[Any, AwsError, zio.aws.sesv2.model.Content.ReadOnly] =
      AwsError.unwrapOptionField("html", html)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.Body
  ) extends zio.aws.sesv2.model.Body.ReadOnly {
    override val text: Optional[zio.aws.sesv2.model.Content.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.text())
        .map(value => zio.aws.sesv2.model.Content.wrap(value))
    override val html: Optional[zio.aws.sesv2.model.Content.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.html())
        .map(value => zio.aws.sesv2.model.Content.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.Body
  ): zio.aws.sesv2.model.Body.ReadOnly = new Wrapper(impl)
}
